@@ -9,109 +9,6 @@ from patientMatcher.server.controllers import validate_response
 from patientMatcher.utils.add import add_node, backend_add_patient, load_demo_patients
 
 
-def test_match_async_request(mock_app, database, async_response_obj, json_patients, test_node):
-    """This function tests the situation when this server is receiving a request containing
-    results from an asynchronous server"""
-
-    # send a POST request with no data to the async endpoint
-    response = mock_app.test_client().post("/async_response", headers=unauth_headers())
-    # server should return a request data is not valid code == 400
-    assert response.status_code == 400
-
-    # provide data object not containing a query id key
-    data = {"key1": "value1"}
-    response = mock_app.test_client().post(
-        "/async_response", data=json.dumps(data), headers=unauth_headers()
-    )
-    # server should return a not authorized response (401)
-    assert response.status_code == 401
-
-    # provide data object with query id not previously saved in database
-    data = {
-        "query_id": async_response_obj["query_id"],
-        "source": "fakey node",
-        "response": {
-            "results": [
-                {
-                    "score": {"patient": 0.8},
-                    "patient": json_patients[1],
-                }
-            ]
-        },
-    }
-
-    response = mock_app.test_client().post(
-        "/async_response", data=json.dumps(data), headers=unauth_headers()
-    )
-    # server should again return a not authorized response (401)
-    assert response.status_code == 401
-
-    # save async_response_obj into database
-    assert mock_app.db["async_responses"].insert_one(async_response_obj).inserted_id
-
-    # send a response with valid data but query patient is not in database
-    response = mock_app.test_client().post(
-        "/async_response", data=json.dumps(data), headers=unauth_headers()
-    )
-
-    # server should return ok code and an error message
-    assert response.status_code == 200
-    resp_data = json.loads(response.data)
-    assert resp_data["message"] == "Error: could not create a valid match object from request data"
-
-    # convert json test patient in mongodb patient object
-    test_patient = mme_patient(json_patients[0])
-
-    # save test patient in database
-    assert mock_app.db["patients"].insert_one(test_patient).inserted_id
-
-    # There should be no match object in database
-    assert mock_app.db["matches"].find_one() is None
-
-    # send a response with valid data
-    # patient object is in database
-    response = mock_app.test_client().post(
-        "/async_response", data=json.dumps(data), headers=unauth_headers()
-    )
-
-    assert response.status_code == 200
-    resp_data = json.loads(response.data)
-    assert resp_data["message"] == "results received, many thanks!"
-
-    # make sure the async response entry was removed from database
-    results = mock_app.db["async_responses"].find({"query_id": async_response_obj["query_id"]})
-    assert len(list(results)) == 0
-
-    # and that match result was saved to server
-    assert mock_app.db["matches"].find_one()
-
-    # re-introduce async response in database for further testing
-    mock_app.db["async_responses"].insert_one(async_response_obj)
-    # test the enpoint by providing a request with no 'response' key
-    data = {
-        "query_id": async_response_obj["query_id"],
-        "source": "fakey node",
-    }
-    response = mock_app.test_client().post(
-        "/async_response", data=json.dumps(data), headers=unauth_headers()
-    )
-    # server should return code 400 (data is not valid)
-    assert response.status_code == 400
-
-    # test the enpoint by providing a request with 'response' key containing
-    # results not conforming to the API
-    data = {
-        "query_id": async_response_obj["query_id"],
-        "source": "fakey node",
-        "response": {"results": ["malformed_result1", "malformed_result2"]},
-    }
-    response = mock_app.test_client().post(
-        "/async_response", data=json.dumps(data), headers=unauth_headers()
-    )
-    # server should return status 422 (Patient data does not conform to API)
-    assert response.status_code == 422
-
-
 def test_heartbeat(mock_app, database, test_client):
     """Test sending a GET request to see if app has a heartbeat"""
 
